@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "orgit-file" "0.4.0"
+(define-package "orgit-file" "20251222.1309"
   "Support for links to files in Git repositories."
   '((emacs  "29.1")
     (compat "30.1")
